You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2010/05/10 15:06:05 UTC

svn commit: r942724 - in /subversion/trunk/subversion/libsvn_wc: entries.c entries.h

Author: julianfoad
Date: Mon May 10 13:06:05 2010
New Revision: 942724

URL: http://svn.apache.org/viewvc?rev=942724&view=rev
Log:
Update some doc strings to reflect WC-NG changes etc.

* subversion/libsvn_wc/entries.h
  (svn_wc__entry_modify, svn_wc__tweak_entry): Reflect WC-NG changes.
  (svn_wc__get_entry): Typo fix.

* subversion/libsvn_wc/entries.c
  (get_entry_access_info): Name the output parameters through which info is
    "returned".

Modified:
    subversion/trunk/subversion/libsvn_wc/entries.c
    subversion/trunk/subversion/libsvn_wc/entries.h

Modified: subversion/trunk/subversion/libsvn_wc/entries.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/entries.c?rev=942724&r1=942723&r2=942724&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/entries.c (original)
+++ subversion/trunk/subversion/libsvn_wc/entries.c Mon May 10 13:06:05 2010
@@ -1325,8 +1325,9 @@ read_entries(apr_hash_t **entries,
 }
 
 
-/* For a given LOCAL_ABSPATH, using DB, return the directory in which the
-   entry information is located, and the entry name to access that entry.
+/* For a given LOCAL_ABSPATH, using DB, set *ADM_ABSPATH to the directory in
+   which the entry information is located, and *ENTRY_NAME to the entry name
+   to access that entry.
 
    KIND and NEED_PARENT_STUB are as in svn_wc__get_entry().
 

Modified: subversion/trunk/subversion/libsvn_wc/entries.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/entries.h?rev=942724&r1=942723&r2=942724&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/entries.h (original)
+++ subversion/trunk/subversion/libsvn_wc/entries.h Mon May 10 13:06:05 2010
@@ -107,17 +107,16 @@ svn_error_t *svn_wc__atts_to_entry(svn_w
 #define SVN_WC__ENTRY_MODIFY_FORCE              0x00020000
 
 
-/* TODO ### Rewrite doc string to mention DB, LOCAL_ABSPATH; not ADM_ACCESS, NAME.
-
-   Modify an entry for NAME in access baton ADM_ACCESS by folding in
+/* Modify the entry for LOCAL_ABSPATH in DB by folding in
    ("merging") changes, and sync those changes to disk.  New values
    for the entry are pulled from their respective fields in ENTRY, and
    MODIFY_FLAGS is a bitmask to specify which of those fields to pay
    attention to, formed from the values SVN_WC__ENTRY_MODIFY_....
-   ADM_ACCESS must hold a write lock.
 
-   NAME can be NULL to specify that the caller wishes to modify the
-   "this dir" entry in ADM_ACCESS.
+   ### Old doc: "ADM_ACCESS must hold a write lock."
+
+   If LOCAL_ABSPATH specifies a directory, its full entry will be modified.
+   To modify its "parent stub" entry, use svn_wc__entry_modify_stub().
 
    "Folding in" a change means, in most cases, simply replacing the field
    with the new value. However, for the "schedule" field, unless
@@ -152,9 +151,9 @@ svn_wc__entry_modify_stub(svn_wc__db_t *
  * make this the entry's new url.  If NEW_REV is valid, make this the
  * entry's working revision.
  *
  * If ALLOW_REMOVAL is TRUE the tweaks might cause the entry NAME to
  * be removed from the hash, if ALLOW_REMOVAL is FALSE this will not
  * happen.
  *
  * THIS_DIR should be true if the LOCAL_ABSPATH refers to a directory, and
  * the information to be edited is not in the stub entry.
@@ -182,7 +181,7 @@ svn_wc__tweak_entry(svn_wc__db_t *db,
  * to handle, than detecting the error and clearing it).
  *
  * If you know the entry is a FILE or DIR, then specify that in KIND. If you
- * are unsure, then specific 'svn_node_unknown' for KIND. This value will be
+ * are unsure, then specify 'svn_node_unknown' for KIND. This value will be
  * used to optimize the access to the entry, so it is best to know the kind.
  * If you specify FILE/DIR, and the entry is *something else*, then
  * SVN_ERR_NODE_UNEXPECTED_KIND will be returned.
@@ -152,9 +151,9 @@ svn_wc__entry_modify_stub(svn_wc__db_t *
  * entry's working revision.
  *
- * If ALLOW_REMOVAL is TRUE the tweaks might cause the entry NAME to
- * be removed from the hash, if ALLOW_REMOVAL is FALSE this will not
- * happen.
+ * If ALLOW_REMOVAL is TRUE the tweaks might cause the entry for
+ * LOCAL_ABSPATH to be removed from the WC; if ALLOW_REMOVAL is FALSE this
+ * will not happen.
  *
  * THIS_DIR should be true if the LOCAL_ABSPATH refers to a directory, and